@@ -126,15 +126,24 @@ xvsprintf (char *fmt, va_list ap)
         return buffer;
       else if (nchars > -1)
         size = nchars + 1;
-      else
+      /* c99 says -1 is an error other than truncation,
+       * which thus will not go away with a larger buffer.
+       * To support older system but not making errors fatal
+       * (ratpoison will abort when trying to get too much memory otherwise),
+       * try to increase a bit but not too much: */
+      else if (size < MAX_LEGACY_SNPRINTF_SIZE)
         size *= 2;
+      else
+	{
+	  free(buffer);
+	  break;
+	}
 
       /* Resize the buffer and try again. */
       buffer = (char *)xrealloc (buffer, size);
     }
 
-  /* Never gets here. */
-  return NULL;
+  return xstrdup("<FAILURE>");
 }
 
 /* Return a new string based on fmt. */
@@ -507,6 +516,7 @@ init_defaults (void)
   defaults.bar_location        = NorthEastGravity;
   defaults.bar_timeout         = 5;
   defaults.bar_border_width    = 1;
+  defaults.bar_in_padding      = 0;
 
   defaults.frame_indicator_timeout = 1;
   defaults.frame_resize_unit = 10;
@@ -516,12 +526,19 @@ init_defaults (void)
   defaults.padding_top    = 0;
   defaults.padding_bottom = 0;
 
+  /* Attempt to load a font */
   defaults.font = load_query_font_set (dpy, DEFAULT_FONT);
   if (defaults.font == NULL)
     {
-      fprintf (stderr, "ratpoison: Cannot load font %s.\n", DEFAULT_FONT);
-      exit (EXIT_FAILURE);
+      PRINT_ERROR (("ratpoison: Cannot load font %s.\n", DEFAULT_FONT));
+      defaults.font = load_query_font_set (dpy, BACKUP_FONT);
+      if (defaults.font == NULL)
+        {
+          PRINT_ERROR (("ratpoison: Cannot load backup font %s . You lose.\n", BACKUP_FONT));
+          exit (EXIT_FAILURE);
+        }
     }
+
   defaults.font_string = xstrdup (DEFAULT_FONT);
   set_extents_of_fontset (defaults.font);
 
@@ -762,10 +779,10 @@ clean_up (void)
 
   free_keymaps ();
   free_aliases ();
+  free_user_commands ();
   free_bar ();
-  free_groups ();
-
   free_window_stuff ();
+  free_groups ();
 
   for (i=0; i<num_screens; i++)
     {
