@@ -1,5 +1,5 @@
 /* Function prototypes for handling string buffers.
- * Copyright (C) 2000, 2001, 2002, 2003 Shawn Betts
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004 Shawn Betts <sabetts@vcn.bc.ca>
  *
  * This file is part of ratpoison.
  *
@@ -7,12 +7,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * ratpoison is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
@@ -24,7 +24,7 @@
 
 #include <stdlib.h>
 
-struct 
+struct
 sbuf
 {
   char *data;
@@ -37,7 +37,9 @@ sbuf
 
 struct sbuf *sbuf_new (size_t initsz);
 void sbuf_free (struct sbuf *b);
+char *sbuf_free_struct (struct sbuf *b);
 char *sbuf_concat (struct sbuf *b, const char *str);
+char *sbuf_nconcat (struct sbuf *b, const char *str, int len);
 char *sbuf_copy (struct sbuf *b, const char *str);
 char *sbuf_clear (struct sbuf *b);
 char *sbuf_get (struct sbuf *b);
